/* Generated by the protocol buffer compiler.  DO NOT EDIT! */
/* Generated from: src/pinba.proto */

#ifndef PROTOBUF_C_src_2fpinba_2eproto__INCLUDED
#define PROTOBUF_C_src_2fpinba_2eproto__INCLUDED

#include <protobuf-c/protobuf-c.h>

PROTOBUF_C__BEGIN_DECLS

#if PROTOBUF_C_VERSION_NUMBER < 1003000
# error This file was generated by a newer version of protobuf-c which is incompatible with your libprotobuf-c headers. Please update your headers.
#elif 1005002 < PROTOBUF_C_MIN_COMPILER_VERSION
# error This file was generated by an older version of protobuf-c which is incompatible with your libprotobuf-c headers. Please regenerate this file with a newer version of protobuf-c.
#endif


typedef struct Pinba__Request Pinba__Request;


/* --- enums --- */


/* --- messages --- */

struct  Pinba__Request
{
  ProtobufCMessage base;
  char *hostname;
  char *server_name;
  char *script_name;
  uint32_t request_count;
  uint32_t document_size;
  uint32_t memory_peak;
  float request_time;
  float ru_utime;
  float ru_stime;
  size_t n_timer_hit_count;
  uint32_t *timer_hit_count;
  size_t n_timer_value;
  float *timer_value;
  size_t n_timer_tag_count;
  uint32_t *timer_tag_count;
  size_t n_timer_tag_name;
  uint32_t *timer_tag_name;
  size_t n_timer_tag_value;
  uint32_t *timer_tag_value;
  size_t n_dictionary;
  char **dictionary;
  protobuf_c_boolean has_status;
  uint32_t status;
};
#define PINBA__REQUEST__INIT \
 { PROTOBUF_C_MESSAGE_INIT (&pinba__request__descriptor) \
, NULL, NULL, NULL, 0, 0, 0, 0, 0, 0, 0,NULL, 0,NULL, 0,NULL, 0,NULL, 0,NULL, 0,NULL, 0, 0 }


/* Pinba__Request methods */
void   pinba__request__init
                     (Pinba__Request         *message);
size_t pinba__request__get_packed_size
                     (const Pinba__Request   *message);
size_t pinba__request__pack
                     (const Pinba__Request   *message,
                      uint8_t             *out);
size_t pinba__request__pack_to_buffer
                     (const Pinba__Request   *message,
                      ProtobufCBuffer     *buffer);
Pinba__Request *
       pinba__request__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data);
void   pinba__request__free_unpacked
                     (Pinba__Request *message,
                      ProtobufCAllocator *allocator);
/* --- per-message closures --- */

typedef void (*Pinba__Request_Closure)
                 (const Pinba__Request *message,
                  void *closure_data);

/* --- services --- */


/* --- descriptors --- */

extern const ProtobufCMessageDescriptor pinba__request__descriptor;

PROTOBUF_C__END_DECLS


#endif  /* PROTOBUF_C_src_2fpinba_2eproto__INCLUDED */
